import click

import dong
import dong.auth


@click.group()
def auth():
    """auth ."""
    pass


@auth.command(help='Authentication related functions.')
def status():
    netrc = dong.auth.load_netrc()
    print(netrc[dong.SERVER_NAME]['login'])


@auth.command(help='Login with your credentials.')
@click.option('-u', '--username', prompt=True)
@click.option('-p', '--password', prompt=True, hide_input=True)
def login(username, password):
    print("U: {} P: {}".format(username, password))



from tinynetrc import Netrc
from pathlib import Path
import os
import sys
import dong

def get_credential_or_exit(message="Can't find any credential information, please login first."):
    netrc = load_netrc()
    login = netrc[dong.SERVER_NAME]['login']
    password = netrc[dong.SERVER_NAME]['password']
    if login is None or password is None:
        print(message)
        sys.exit(1)

    return (login, password)


def load_netrc():
    file = os.path.join(os.path.expanduser('~'), '.netrc')
    try:
        Path(file).touch()
    except PermissionError: 
        pass
    return Netrc(file=file)



import click
import webbrowser
import os
from dong import utils

@click.group()
def local():
    """Local test."""
    pass

@local.command()
@click.option('--package-path', default=None, help='Path to the training program python package. Default to ./PROJECT_NAME and PROJECT_NAME got from ./setup.py')
@click.argument('args', nargs=-1, metavar='[-- [ARGS]]')
@click.pass_context
def train(ctx, package_path, args):
    """Execute local training test with [ARGS].
    """

    setup_py_path = './setup.py' if package_path is None else os.path.join(os.path.dirname(package_path),
                                                                           'setup.py')
    module_name = utils.get_project_name(setup_py_path)
    if module_name == '' or len(module_name.split('/')) > 1:
        click.secho('setup.py not found under ' + ('current working directory' if package_path is None else os.path.dirname(package_path)),
                    fg='red',
                    err=True)
        ctx.exit(1)
        return

    if package_path is None:
        package_path = './' + module_name        

    print('Only support HELP message for local train for now')
    print('Use dong ML project: ' + module_name)
    print('Project path: ' + os.path.abspath(os.path.dirname(package_path)))
    print('Opening target project homepage......')
    webbrowser.open(utils.get_project_url(setup_py_path), new=2)
    



import contextlib
import os
import shutil
import subprocess
import sys
import tempfile
import time
import json

import click
import dong
from dong import auth
from dong import net
from dong import utils
from dong.decorators import login_required
import dong.httpclient as httpclient
from tabulate import tabulate


@click.group()
def model():
    """Model management."""
    pass

@model.command()
@click.option('-j', '--job-name')
def ls(job_name):
    """jobs listing"""
    (login, password) = auth.get_credential_or_exit()
    headers = net.authorization_headers(password)
    try:
        r = httpclient.get('api/v1/train/{}/'.format(job_name), headers=headers)
        result = r.json()
        train_jobs = [(result['job_name'], result['status'], result['message'])]
        print("\n")
        print(tabulate(train_jobs, headers=['JOB NAME', 'STATUS', 'MESSAGE'], tablefmt='plain'))
        print("\n")

    except Exception as e:
        output = "Can't get any status of training job: {}, stopped.".format(job_name)



import click
import os
import dong
import pkg_resources 

version_number = pkg_resources.require("dong")[0].version
@click.command(help='Print version and exit.', add_help_option=False)
def version():
    click.secho("dong " + version_number, fg='green')



from setuptools import setup, find_packages
from setuptools.command.install import install
import os, sys
from pathlib import Path


def read_file(filename):
    filepath = os.path.join(
        os.path.dirname(os.path.dirname(__file__)), filename)
    if os.path.exists(filepath):
        return open(filepath).read()
    else:
        return ''

class PostInstallCommand(install):
    """Post-installation for installation mode."""

    def run(self):

        install.run(self)
        
        _bash_profile_path = str(Path.home()) + '/.bash_profile'
        _click_completion_activation_str = 'eval "$(_DONG_COMPLETE=source dong)"'

        # Any case that user can't use bash_profile?
        if os.path.exists(_bash_profile_path):
            with open(_bash_profile_path, 'r+') as user_bashrc:
                if _click_completion_activation_str in user_bashrc.read():
                    return

        Path(_bash_profile_path).touch()
        # ToDo: exception handling and warn users that bash_profile is modified
        with open(_bash_profile_path, 'a') as user_bashrc:
            user_bashrc.write(_click_completion_activation_str)
    
setup(
    name='dong',
    version='0.2.1.8',
    description='Universal Command Line Interface for Libgirl AI Platform',
    long_description=read_file('readme.md'),
    long_description_content_type="text/markdown",
    url='https://dong.libgirl.com/',
    author='Team Libgirl',
    author_email='team@libgirl.com',
    license='Apache License 2.0',
    packages=find_packages(),

    ## Don't do auto activation for bash autocompletion for now. We need to provide installation option to do it.
    # cmdclass={
    #     'install': PostInstallCommand,
    # },
    install_requires=['requests==2.22.0', 'tinynetrc==1.3.0', 'click==7.0', 'tabulate'],
    include_package_data=True,
    zip_safe=False,
    test_suite='tests',
    setup_requires=["pytest-runner"],
    tests_require=["pytest"],
    entry_points='''
        [console_scripts]
        dong=dong.cliapp:main
    '''
)
